@@ -2,9 +2,9 @@ package Dist::Zilla::PluginBundle::Author::DBOOK;
 
 use Moose;
 use Scalar::Util 'blessed';
-with 'Dist::Zilla::Role::PluginBundle::Easy';
+with 'Dist::Zilla::Role::PluginBundle::Easy', 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 sub mvp_multivalue_args { qw/mma_WriteMakefile_arg mma_header mma_footer mma_test_file mma_exe_file/ }
 
@@ -74,6 +74,7 @@ built by DBOOK
  [@Author::DBOOK]
  makemaker = awesome
  mma_test_file = t/*.t
+ Git::GatherDir.exclude_filename[0] = bad_file
 
 =head1 DESCRIPTION
 
@@ -163,6 +164,10 @@ the upload to CPAN.
 
 =head1 OPTIONS
 
+This bundle composes the L<Dist::Zilla::Role::PluginBundle::Config::Slicer>
+role, so options for any included plugin may be specified in that format.
+Additionally, the following options are provided.
+
 =head2 github_user
 
  github_user = gitster
